==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkAnnotationLink.java <==
// java wrapper for vtkAnnotationLink object
//

package vtk;
import vtk.*;

public class vtkAnnotationLink extends vtkAnnotationLayersAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetAnnotationLayers_2();
  public vtkAnnotationLayers GetAnnotationLayers() {
    long temp = GetAnnotationLayers_2();

    if (temp == 0) return null;
    return (vtkAnnotationLayers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAnnotationLayers_3(vtkAnnotationLayers id0);
  public void SetAnnotationLayers(vtkAnnotationLayers id0)
    { SetAnnotationLayers_3(id0); }

  private native void SetCurrentSelection_4(vtkSelection id0);
  public void SetCurrentSelection(vtkSelection id0)
    { SetCurrentSelection_4(id0); }

  private native long GetCurrentSelection_5();
  public vtkSelection GetCurrentSelection() {
    long temp = GetCurrentSelection_5();

    if (temp == 0) return null;
    return (vtkSelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void AddDomainMap_6(vtkTable id0);
  public void AddDomainMap(vtkTable id0)
    { AddDomainMap_6(id0); }

  private native void RemoveDomainMap_7(vtkTable id0);
  public void RemoveDomainMap(vtkTable id0)
    { RemoveDomainMap_7(id0); }

  private native void RemoveAllDomainMaps_8();
  public void RemoveAllDomainMaps()
    { RemoveAllDomainMaps_8(); }

  private native int GetNumberOfDomainMaps_9();
  public int GetNumberOfDomainMaps()
    { return GetNumberOfDomainMaps_9(); }

  private native long GetDomainMap_10(int id0);
  public vtkTable GetDomainMap(int id0) {
    long temp = GetDomainMap_10(id0);

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_11();
  public int GetMTime()
    { return GetMTime_11(); }

  public vtkAnnotationLink() { super(); }

  public vtkAnnotationLink(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkAnnotationLink.java <==
// java wrapper for vtkAnnotationLink object
//

package vtk;
import vtk.*;

public class vtkAnnotationLink extends vtkAnnotationLayersAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetAnnotationLayers_2();
  public vtkAnnotationLayers GetAnnotationLayers() {
    long temp = GetAnnotationLayers_2();

    if (temp == 0) return null;
    return (vtkAnnotationLayers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAnnotationLayers_3(vtkAnnotationLayers id0);
  public void SetAnnotationLayers(vtkAnnotationLayers id0)
    { SetAnnotationLayers_3(id0); }

  private native void SetCurrentSelection_4(vtkSelection id0);
  public void SetCurrentSelection(vtkSelection id0)
    { SetCurrentSelection_4(id0); }

  private native long GetCurrentSelection_5();
  public vtkSelection GetCurrentSelection() {
    long temp = GetCurrentSelection_5();

    if (temp == 0) return null;
    return (vtkSelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void AddDomainMap_6(vtkTable id0);
  public void AddDomainMap(vtkTable id0)
    { AddDomainMap_6(id0); }

  private native void RemoveDomainMap_7(vtkTable id0);
  public void RemoveDomainMap(vtkTable id0)
    { RemoveDomainMap_7(id0); }

  private native void RemoveAllDomainMaps_8();
  public void RemoveAllDomainMaps()
    { RemoveAllDomainMaps_8(); }

  private native int GetNumberOfDomainMaps_9();
  public int GetNumberOfDomainMaps()
    { return GetNumberOfDomainMaps_9(); }

  private native long GetDomainMap_10(int id0);
  public vtkTable GetDomainMap(int id0) {
    long temp = GetDomainMap_10(id0);

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_11();
  public int GetMTime()
    { return GetMTime_11(); }

  public vtkAnnotationLink() { super(); }

  public vtkAnnotationLink(long id) { super(id); }
  public native long   VTKInit();

}
